@@ -3,6 +3,7 @@
 
 from __future__ import annotations
 
+import sys
 import asyncio
 from asyncio import Queue
 from typing import (
@@ -13,8 +14,16 @@ from typing import (
 from pathlib import Path
 import contextvars
 import abc
+from dataclasses import dataclass
+
+if TYPE_CHECKING:
+  import tomli as tomllib
+else:
+  try:
+    import tomllib
+  except ModuleNotFoundError:
+    import tomli as tomllib
 
-import tomli
 import structlog
 
 from .httpclient import session
@@ -30,12 +39,31 @@ Entry = Dict[str, Any]
 Entry.__doc__ = '''The configuration `dict` for an entry.'''
 Entries = Dict[str, Entry]
 VersData = Dict[str, str]
-VersionResult = Union[None, str, List[str], Exception]
+
+if sys.version_info[:2] >= (3, 10):
+  @dataclass(kw_only=True)
+  class RichResult:
+    version: str
+    url: Optional[str] = None
+
+    def __str__(self):
+      return self.version
+else:
+  @dataclass
+  class RichResult:
+    version: str
+    url: Optional[str] = None
+
+    def __str__(self):
+      return self.version
+
+VersionResult = Union[None, str, RichResult, List[Union[str, RichResult]], Exception]
 VersionResult.__doc__ = '''The result of a `get_version` check.
 
 * `None` - No version found.
 * `str` - A single version string is found.
-* `List[str]` - Multiple version strings are found. :ref:`list options` will be applied.
+* `RichResult` - A version string with additional information.
+* `List[Union[str, RichResult]]` - Multiple version strings with or without additional information are found. :ref:`list options` will be applied.
 * `Exception` - An error occurred.
 '''
 
@@ -56,8 +84,8 @@ class KeyManager:
     if file is not None:
       try:
         with file.open('rb') as f:
-          keys = tomli.load(f)['keys']
-      except (OSError, tomli.TOMLDecodeError) as e:
+          keys = tomllib.load(f)['keys']
+      except (OSError, tomllib.TOMLDecodeError) as e:
         raise FileLoadError('keyfile', str(file), e)
     else:
       keys = {}
@@ -103,6 +131,7 @@ class Result(NamedTuple):
   name: str
   version: str
   conf: Entry
+  url: Optional[str]
 
 class BaseWorker:
   '''The base class for defining `Worker` classes for source plugins.
