@@ -5,11 +5,12 @@ from __future__ import annotations
 
 import urllib.parse
 
-GITEA_URL = 'https://%s/api/v1/repos/%s/commits?sha=%s'
+GITEA_URL = 'https://%s/api/v1/repos/%s/commits'
 GITEA_MAX_TAG = 'https://%s/api/v1/repos/%s/tags'
 
 from nvchecker.api import (
-  VersionResult, Entry, AsyncCache, KeyManager,
+  VersionResult, RichResult, Entry,
+  AsyncCache, KeyManager,
 )
 
 async def get_version(
@@ -17,14 +18,16 @@ async def get_version(
   cache: AsyncCache, keymanager: KeyManager,
 ) -> VersionResult:
   repo = urllib.parse.quote(conf['gitea'])
-  br = conf.get('branch', 'master')
+  br = conf.get('branch')
   host = conf.get('host', 'gitea.com')
   use_max_tag = conf.get('use_max_tag', False)
 
   if use_max_tag:
     url = GITEA_MAX_TAG % (host, repo)
   else:
-    url = GITEA_URL % (host, repo, br)
+    url = GITEA_URL % (host, repo)
+    if br:
+      url += '?sha=' + br
 
   # Load token from config
   token = conf.get('token')
@@ -40,7 +43,14 @@ async def get_version(
 
   data = await cache.get_json(url, headers = headers)
   if use_max_tag:
-    version = [tag["name"] for tag in data]
+    return [
+      RichResult(
+        version = tag['name'],
+        url = f'https://{host}/{conf["gitea"]}/releases/tag/{tag["name"]}',
+      ) for tag in data
+    ]
   else:
-    version = data[0]['commit']['committer']['date'].split('T', 1)[0].replace('-', '')
-  return version
+    return RichResult(
+      version = data[0]['commit']['committer']['date'].split('T', 1)[0].replace('-', ''),
+      url = data[0]['html_url'],
+    )
